@@ -1,20 +1,14 @@
 # vim:fileencoding=utf-8
 
-from io import open
 import json
 import logging
 import threading
+from io import open
 
-logger = logging.getLogger('pycountry.db')
-
-try:
-    unicode
-except NameError:
-    unicode = str
+logger = logging.getLogger("pycountry.db")
 
 
-class Data(object):
-
+class Data:
     def __init__(self, **fields):
         self._fields = fields
 
@@ -24,14 +18,14 @@ class Data(object):
         return self._fields[key]
 
     def __setattr__(self, key, value):
-        if key != '_fields':
+        if key != "_fields":
             self._fields[key] = value
         super(Data, self).__setattr__(key, value)
 
     def __repr__(self):
         cls_name = self.__class__.__name__
-        fields = ', '.join('%s=%r' % i for i in sorted(self._fields.items()))
-        return '%s(%s)' % (cls_name, fields)
+        fields = ", ".join("%s=%r" % i for i in sorted(self._fields.items()))
+        return "%s(%s)" % (cls_name, fields)
 
     def __dir__(self):
         return dir(self.__class__) + list(self._fields)
@@ -43,10 +37,11 @@ def lazy_load(f):
             with self._load_lock:
                 self._load()
         return f(self, *args, **kw)
+
     return load_if_needed
 
 
-class Database(object):
+class Database:
 
     data_class_base = Data
     data_class_name = None
@@ -68,9 +63,10 @@ class Database(object):
         self.indices = {}
 
         self.data_class = type(
-            self.data_class_name, (self.data_class_base,), {})
+            self.data_class_name, (self.data_class_base,), {}
+        )
 
-        with open(self.filename, 'r', encoding="utf-8") as f:
+        with open(self.filename, "r", encoding="utf-8") as f:
             tree = json.load(f)
 
         for entry in tree[self.root_key]:
@@ -78,14 +74,18 @@ class Database(object):
             self.objects.append(obj)
             # Inject into index.
             for key, value in entry.items():
+                # Lookups and searches are case insensitive. Normalize
+                # here.
+                value = value.lower()
                 if key in self.no_index:
                     continue
                 index = self.indices.setdefault(key, {})
                 if value in index:
                     logger.debug(
-                        '%s %r already taken in index %r and will be '
-                        'ignored. This is an error in the databases.' %
-                        (self.data_class_name, value, key))
+                        "%s %r already taken in index %r and will be "
+                        "ignored. This is an error in the databases."
+                        % (self.data_class_name, value, key)
+                    )
                 index[value] = obj
 
         self._is_loaded = True
@@ -102,27 +102,46 @@ class Database(object):
 
     @lazy_load
     def get(self, **kw):
+        kw.setdefault("default", None)
+        default = kw.pop("default")
         if len(kw) != 1:
-            raise TypeError('Only one criteria may be given')
+            raise TypeError("Only one criteria may be given")
         field, value = kw.popitem()
-        return self.indices[field][value]
+        if not isinstance(value, str):
+            raise LookupError()
+        # Normalize for case-insensitivity
+        value = value.lower()
+        index = self.indices[field]
+        try:
+            return index[value]
+        except KeyError:
+            # Pythonic APIs implementing     get() shouldn't raise KeyErrors.
+            # Those are a bit unexpected and they should rather support
+            # returning `None` by default and allow customization.
+            return default
 
     @lazy_load
     def lookup(self, value):
-        # try relatively quick exact matches first
-        if isinstance(value, (str, unicode)):
-            value = value.lower()
+        if not isinstance(value, str):
+            raise LookupError()
 
+        # Normalize for case-insensitivity
+        value = value.lower()
+
+        # Use indexes first
         for key in self.indices:
             try:
                 return self.indices[key][value]
             except LookupError:
                 pass
-        # then try slower case-insensitive lookups
+
+        # Use non-indexed values now. Avoid going through indexed values.
         for candidate in self:
-            for v in candidate._fields.values():
+            for k in self.no_index:
+                v = candidate._fields.get(k)
                 if v is None:
                     continue
                 if v.lower() == value:
                     return candidate
-        raise LookupError('Could not find a record for %r' % value)
+
+        raise LookupError("Could not find a record for %r" % value)
